
EDITOR_CKEDITOR = 'CKEDITOR'
EDITOR_CKEDITOR_UPLOADER = 'CKEDITOR_UPLOADER'
EDITOR_MARTOR = 'MARTOR'

FLATPAGE_EDITORS = {
    EDITOR_CKEDITOR: 'ckeditor.widgets.CKEditorWidget',
    EDITOR_CKEDITOR_UPLOADER: (
        'ckeditor_uploader.widgets.CKEditorUploadingWidget'),
    EDITOR_MARTOR: 'martor.widgets.AdminMartorWidget'
}
